@@ -96,7 +96,7 @@ _SUB_CATEGORIES = {
             TokenClassWithTag.i_answer,
             TokenClassWithTag.i_header,
             TokenClassWithTag.i_question,
-            TokenClasses.other,
+            BioTag.outside,
         ],
     }
 }
@@ -167,7 +167,6 @@ class FunsdBuilder(DataFlowBaseBuilder):
             name_as_key=True,
         )[LayoutType.word][WordType.token_tag]
         df = MapData(df, xfund_to_image(load_image, False, category_names_mapping, ner_token_to_id_mapping))
-        df = MapData(df, xfund_to_image(load_image, False, category_names_mapping, ner_token_to_id_mapping))
         if self.categories.is_cat_to_sub_cat():
             df = MapData(
                 df,
