@@ -33,6 +33,8 @@ class PredictorBase(ABC):
     Abstract base class for all types of predictors (e.g. object detectors language models, ...)
     """
 
+    name: str
+
     def __new__(cls, *args, **kwargs):  # type: ignore # pylint: disable=W0613
         requirements = cls.get_requirements()
         name = cls.__name__ if hasattr(cls, "__name__") else cls.__class__.__name__
@@ -374,3 +376,19 @@ class LanguageDetector(PredictorBase):
         Returns a list of possible detectable languages
         """
         return list(self.categories.values())
+
+
+class ImageTransformer(PredictorBase):
+    """
+    Abstract base class for transforming an image. The :meth:`transform` accepts a numpy array and returns the same.
+    """
+
+    @abstractmethod
+    def transform(self, np_img: ImageType) -> ImageType:
+        """
+        Abstract method transform
+        """
+        raise NotImplementedError
+
+    def clone(self) -> PredictorBase:
+        return self.__class__()
