@@ -225,7 +225,7 @@ Train configs
 """
 
 import os
-from typing import Dict, List, Tuple
+from typing import List, Mapping, Tuple
 
 import numpy as np
 from tensorpack.tfutils import collect_env_info  # pylint: disable=E0401
@@ -235,6 +235,7 @@ from tensorpack.utils import logger  # pylint: disable=E0401
 from tensorpack.utils.gpu import get_num_gpu
 
 from .....utils.metacfg import AttrDict
+from .....utils.settings import ObjectTypes
 
 # pylint: enable=import-error
 
@@ -242,7 +243,7 @@ from .....utils.metacfg import AttrDict
 __all__ = ["train_frcnn_config", "model_frcnn_config"]
 
 
-def model_frcnn_config(config: AttrDict, categories: Dict[str, str], print_summary: bool = True) -> None:
+def model_frcnn_config(config: AttrDict, categories: Mapping[str, ObjectTypes], print_summary: bool = True) -> None:
     """
     Sanity checks for Tensorpack Faster-RCNN config settings, where the focus lies on the model for predicting.
     It will update the config instance.
@@ -253,7 +254,8 @@ def model_frcnn_config(config: AttrDict, categories: Dict[str, str], print_summa
     """
 
     config.freeze(False)
-    categories = categories.copy()
+
+    categories = {str(key): categories[val] for key, val in enumerate(categories, 1)}
     categories[0] = "BG"
     config.DATA.CLASS_NAMES = list(categories.values())
     config.DATA.CLASS_DICT = categories
@@ -345,9 +347,7 @@ def train_frcnn_config(config: AttrDict) -> Tuple[List[Tuple[int, int]], List[Tu
     for idx, steps in enumerate(config.TRAIN.LR_SCHEDULE[:-1]):
         mult = 0.1 ** (idx + 1)
         lr_schedule.append((steps * float(factor) // step_num, config.TRAIN.BASE_LR * float(mult)))
-    logger.info("Warm Up Schedule (steps, value): %s", str(warmup_schedule))
-    logger.info("LR Schedule (epochs, value): %s", str(lr_schedule))
 
     config.freeze()
-    logger.info("Config: ------------------------------------------\n %s", str(config))
+    logger.info("Config: \n %s", str(config), config.to_dict())
     return warmup_schedule, lr_schedule, step_num
