@@ -16,8 +16,8 @@ import numpy as np
 from tensorpack.predict.base import OfflinePredictor  # pylint: disable=E0401
 
 from ....utils.file_utils import scipy_available
+from ....utils.transform import InferenceResize
 from ...base import DetectionResult
-from ...common import InferenceResize
 from .common import clip_boxes
 
 if scipy_available():
