@@ -20,6 +20,7 @@ TP Faster RCNN model as predictor for deepdoctection pipeline
 """
 
 from copy import copy
+from pathlib import Path
 from typing import List, Mapping, Optional, Union
 
 from ..utils.detection_types import ImageType, Requirement
@@ -53,7 +54,7 @@ class TPFrcnnDetector(TensorpackPredictor, ObjectDetector):
         weights_path = ModelDownloadManager.maybe_download_weights_and_configs("item/model-162000.data-00000-of-00001")
         categories = ModelCatalog.get_profile("item/model-162000.data-00000-of-00001").categories
 
-        tp_predictor = TPFrcnnDetector(config_path,weights_path,categories)
+        tp_predictor = TPFrcnnDetector("tp_frcnn", config_path,weights_path,categories)  # first argument is only a name
         detection_results = tp_predictor.predict(bgr_image_np_array)
 
     """
@@ -85,6 +86,7 @@ class TPFrcnnDetector(TensorpackPredictor, ObjectDetector):
         :param ignore_mismatch: When True will ignore mismatches between checkpoint weights and models. This is needed
                                 if a pre-trained model is to be fine-tuned on a custom dataset.
         """
+        self.name = "_".join(Path(path_weights).parts[-3:])
         self.path_yaml = path_yaml
         self.categories = copy(categories)  # type: ignore
         self.config_overwrite = config_overwrite
