@@ -28,7 +28,6 @@ from .cocostruct import *
 from .maputils import *
 from .match import *
 from .misc import *
-from .pagestruct import *
 from .pascalstruct import *
 from .prodigystruct import *
 from .pubstruct import *
@@ -39,7 +38,7 @@ if detectron2_available():
     from .d2struct import *
 
 if pytorch_available() and transformers_available():
-    from .laylmstruct import *  # pylint: disable = W0622
+    from .laylmstruct import *
 
 
 # Mapper
