@@ -27,6 +27,7 @@ from ..datapoint.box import BoundingBox
 from ..datapoint.image import Image
 from ..utils.detection_types import JsonDict
 from ..utils.fs import load_image_from_file
+from ..utils.settings import ObjectTypes
 from .maputils import MappingContextManager, curry, maybe_get_fake_score
 
 
@@ -38,7 +39,7 @@ def coco_to_image(
     filter_empty_image: bool,
     fake_score: bool,
     coarse_mapping: Optional[Mapping[int, int]] = None,
-    coarse_sub_cat_name: Optional[str] = None,
+    coarse_sub_cat_name: Optional[ObjectTypes] = None,
 ) -> Optional[Image]:
 
     """
@@ -53,7 +54,7 @@ def coco_to_image(
                        will be added.
     :param coarse_mapping: A mapping to map categories into broader categories. Note that the coarser categories must
                            already be included in the original mapping.
-    :param coarse_sub_cat_name: A name to be provided as sub category key for a coarse mapping. If
+    :param coarse_sub_cat_name: A name to be provided as sub category key for a coarse mapping.
     :return: Image
     """
 
@@ -118,7 +119,9 @@ def image_to_coco(dp: Image) -> Tuple[JsonDict, List[JsonDict]]:
     :return: A tuple of dicts, the first corresponding to the coco-image object, the second to their coco-annotations
     """
 
-    assert isinstance(dp, Image), f"datapoints must be of type Image, is of type {type(dp)}"
+    if not isinstance(dp, Image):
+        raise TypeError(f"datapoints must be of type Image, is of type {type(dp)}")
+
     img: JsonDict = {}
     anns: List[JsonDict] = []
 
