@@ -21,17 +21,22 @@ Module for mapping annotations into standard Detectron2 dataset dict
 
 
 import os.path
-from typing import Dict, List, Optional, Union
+from typing import Dict, List, Optional, Sequence, Union
 
 from detectron2.structures import BoxMode
 
 from ..datapoint.image import Image
 from ..mapper.maputils import curry
 from ..utils.detection_types import JsonDict
+from ..utils.settings import ObjectTypes
 
 
 @curry
-def image_to_d2_frcnn_training(dp: Image, add_mask: bool = False) -> Optional[JsonDict]:
+def image_to_d2_frcnn_training(
+    dp: Image,
+    add_mask: bool = False,
+    category_names: Optional[Union[str, ObjectTypes, Sequence[Union[str, ObjectTypes]]]] = None,
+) -> Optional[JsonDict]:
     """
     Maps an image to a standard dataset dict as described in
     https://detectron2.readthedocs.io/en/latest/tutorials/datasets.html. It further checks if the image is physically
@@ -40,10 +45,10 @@ def image_to_d2_frcnn_training(dp: Image, add_mask: bool = False) -> Optional[Js
 
     :param dp: Image
     :param add_mask: True is not implemented (yet).
+    :param category_names: A list of category names for training a model. Pass nothing to train with all annotations
     :return: Dict with 'image', 'width', 'height', 'image_id', 'annotations' where 'annotations' is a list of dict
              with 'bbox_mode' (D2 internal bounding box description), 'bbox' and 'category_id'.
     """
-
     if not os.path.isfile(dp.location) and dp.image is None:
         return None
 
@@ -55,7 +60,7 @@ def image_to_d2_frcnn_training(dp: Image, add_mask: bool = False) -> Optional[Js
     output["height"] = dp.height
     output["image_id"] = dp.image_id
 
-    anns = dp.get_annotation()
+    anns = dp.get_annotation(category_names=category_names)
 
     if not anns:
         return None
