@@ -25,7 +25,6 @@ from typing import Any, Callable, Dict, List, Literal, Mapping, NewType, Optiona
 
 import numpy as np
 from cv2 import INTER_LINEAR
-from dataflow.dataflow.imgaug.transform import ResizeTransform
 
 from ..datapoint.annotation import ContainerAnnotation
 from ..datapoint.convert import box_to_point4, point4_to_box
@@ -33,7 +32,16 @@ from ..datapoint.image import Image
 from ..utils.detection_types import JsonDict
 from ..utils.develop import deprecated
 from ..utils.file_utils import pytorch_available, transformers_available
-from ..utils.settings import names
+from ..utils.settings import (
+    BioTag,
+    DatasetType,
+    LayoutType,
+    ObjectTypes,
+    PageType,
+    WordType,
+    token_class_tag_to_token_class_with_tag,
+)
+from ..utils.transform import ResizeTransform
 from .maputils import curry
 
 if pytorch_available():
@@ -65,7 +73,7 @@ of PyTorch/TensorFlow tensors or NumPy arrays.
 
 DataCollator = NewType("DataCollator", Callable[[List[InputDataClass]], Dict[str, Any]])  # type: ignore
 
-_CLS_BOX = [0.0, 0.0, 0.0, 0.0]
+_CLS_BOX = [0.0, 0.0, 1000.0, 1000.0]
 _SEP_BOX = [1000.0, 1000.0, 1000.0, 1000.0]
 
 
@@ -74,7 +82,7 @@ _SEP_BOX = [1000.0, 1000.0, 1000.0, 1000.0]
 def image_to_layoutlm(
     dp: Image,
     tokenizer: "PreTrainedTokenizer",
-    categories_dict_name_as_key: Optional[Dict[str, str]] = None,
+    categories_dict_name_as_key: Optional[Dict[ObjectTypes, str]] = None,
     input_width: int = 1000,
     input_height: int = 1000,
 ) -> LayoutLMFeatures:
@@ -94,17 +102,19 @@ def image_to_layoutlm(
 
     output: JsonDict = {}
 
-    anns = dp.get_annotation_iter(category_names=names.C.WORD)
+    anns = dp.get_annotation_iter(category_names=LayoutType.word)
     all_tokens = []
     all_boxes = []
     all_ann_ids = []
     words: List[str] = []
     all_input_ids = []
     for ann in anns:
-        char_cat = ann.get_sub_category(names.C.CHARS)
-        assert isinstance(char_cat, ContainerAnnotation)
+        char_cat = ann.get_sub_category(WordType.characters)
+        if not isinstance(char_cat, ContainerAnnotation):
+            raise TypeError(f"char_cat must be of type ContainerAnnotation but is of type {type(char_cat)}")
         word = char_cat.value
-        assert isinstance(word, str)
+        if not isinstance(word, str):
+            raise ValueError(f"word must be of type str but is of type {type(word)}")
         words.append(word)
         word_tokens = tokenizer.tokenize(word)
         all_input_ids.extend(tokenizer.convert_tokens_to_ids(word_tokens))
@@ -114,7 +124,7 @@ def image_to_layoutlm(
             box = ann.image.get_embedding(dp.image_id)
         else:
             box = ann.bounding_box
-        assert box is not None
+        assert box is not None, box
         if not box.absolute_coords:
             box = box.transform(dp.width, dp.height, absolute_coords=True)
         box = box.to_list(mode="xyxy")
@@ -124,21 +134,23 @@ def image_to_layoutlm(
             all_ann_ids.extend([ann.annotation_id] * len(word_tokens))
 
         if (
-            names.C.SE in ann.sub_categories
-            and names.NER.TAG in ann.sub_categories
+            WordType.token_class in ann.sub_categories
+            and WordType.tag in ann.sub_categories
             and categories_dict_name_as_key is not None
         ):
-            semantic_label = ann.get_sub_category(names.C.SE).category_name
-            bio_tag = ann.get_sub_category(names.NER.TAG).category_name
-            if bio_tag == "O":
-                category_name = "O"
+            semantic_label = ann.get_sub_category(WordType.token_class).category_name
+            bio_tag = ann.get_sub_category(WordType.tag).category_name
+            category_name: Union[ObjectTypes, BioTag]
+            if bio_tag is BioTag.outside:
+                category_name = BioTag.outside
             else:
-                category_name = bio_tag + "-" + semantic_label
+                # category_name = bio_tag + "-" + semantic_label
+                category_name = token_class_tag_to_token_class_with_tag(semantic_label, bio_tag)  # type: ignore
             output["label"] = int(categories_dict_name_as_key[category_name])
 
         if dp.summary is not None and categories_dict_name_as_key is not None:
-            category_name = dp.summary.get_sub_category(names.C.DOC).category_name
-            output["label"] = int(categories_dict_name_as_key[category_name])
+            summary_cat_name = dp.summary.get_sub_category(PageType.document_type).category_name
+            output["label"] = int(categories_dict_name_as_key[summary_cat_name])  # type: ignore
 
     all_boxes = [_CLS_BOX] + all_boxes + [_SEP_BOX]
     all_ann_ids = ["CLS"] + all_ann_ids + ["SEP"]
@@ -212,36 +224,42 @@ def image_to_raw_layoutlm_features(
     all_ann_ids = []
     all_words = []
     all_boxes = []
-    all_labels = []
+    all_labels: List[int] = []
 
-    anns = dp.get_annotation_iter(category_names=names.C.WORD)
+    anns = dp.get_annotation_iter(category_names=LayoutType.word)
 
     for ann in anns:
         all_ann_ids.append(ann.annotation_id)
-        char_cat = ann.get_sub_category(names.C.CHARS)
-        assert isinstance(char_cat, ContainerAnnotation)
+        char_cat = ann.get_sub_category(WordType.characters)
+        if not isinstance(char_cat, ContainerAnnotation):
+            raise TypeError(f"char_cat must be of type ContainerAnnotation but is of type {type(char_cat)}")
         word = char_cat.value
-        assert isinstance(word, str)
+        if not isinstance(word, str):
+            raise ValueError(f"word must be of type str but is of type {type(word)}")
         all_words.append(word)
 
         if ann.image is not None:
             box = ann.image.get_embedding(dp.image_id)
         else:
             box = ann.bounding_box
-        assert box is not None
+        assert box is not None, box
         if not box.absolute_coords:
             box = box.transform(dp.width, dp.height, absolute_coords=True)
         all_boxes.append(box.to_list(mode="xyxy"))
 
         if (
-            names.NER.TOK in ann.sub_categories
+            WordType.token_tag in ann.sub_categories
             and categories_dict_name_as_key is not None
-            and dataset_type == names.DS.TYPE.TOK
+            and dataset_type == DatasetType.token_classification
         ):
-            all_labels.append(int(ann.get_sub_category(names.NER.TOK).category_id) - 1)
+            all_labels.append(int(ann.get_sub_category(WordType.token_tag).category_id) - 1)
 
-    if dp.summary is not None and categories_dict_name_as_key is not None and dataset_type == names.DS.TYPE.SEQ:
-        category_name = dp.summary.get_sub_category(names.C.DOC).category_name
+    if (
+        dp.summary is not None
+        and categories_dict_name_as_key is not None
+        and dataset_type == DatasetType.sequence_classification
+    ):
+        category_name = dp.summary.get_sub_category(PageType.document_type).category_name
         all_labels.append(int(categories_dict_name_as_key[category_name]) - 1)
 
     boxes = np.asarray(all_boxes, dtype="float32")
@@ -286,6 +304,10 @@ def features_to_pt_tensors(features: LayoutLMFeatures) -> LayoutLMFeatures:
     features["bbox"] = torch.tensor(features["bbox"], dtype=torch.long)
     if "labels" in features:
         features["labels"] = torch.tensor(features["labels"], dtype=torch.long)
+    if "images" in features:
+        features["images"] = [
+            torch.as_tensor(image.astype("float32").transpose(2, 0, 1)) for image in features["images"]
+        ]
     return features
 
 
@@ -328,10 +350,12 @@ def raw_features_to_layoutlm_features(
         raw_features = [raw_features]
 
     _has_token_labels = (
-        raw_features[0]["dataset_type"] == names.DS.TYPE.TOK and raw_features[0].get("labels") is not None
+        raw_features[0]["dataset_type"] == DatasetType.token_classification
+        and raw_features[0].get("labels") is not None
     )
     _has_sequence_labels = (
-        raw_features[0]["dataset_type"] == names.DS.TYPE.SEQ and raw_features[0].get("labels") is not None
+        raw_features[0]["dataset_type"] == DatasetType.sequence_classification
+        and raw_features[0].get("labels") is not None
     )
     _has_labels = bool(_has_token_labels or _has_sequence_labels)
 
@@ -345,6 +369,7 @@ def raw_features_to_layoutlm_features(
     )
 
     image_ids = []
+    images = []
     widths = []
     heights = []
 
@@ -359,6 +384,8 @@ def raw_features_to_layoutlm_features(
             # we might get more batches when we allow to get returned overflowing tokens
             batch_index_orig = tokenized_inputs["overflow_to_sample_mapping"][batch_index]
 
+        if "image" in raw_features[batch_index_orig]:
+            images.append(raw_features[batch_index_orig]["image"])
         image_ids.append(raw_features[batch_index_orig]["image_id"])
         widths.append(raw_features[batch_index_orig]["width"])
         heights.append(raw_features[batch_index_orig]["height"])
@@ -415,6 +442,10 @@ def raw_features_to_layoutlm_features(
         "tokens": tokens,
     }
 
+    # will only add the image to features if it has been passed as raw feature
+    if images:
+        input_dict["images"] = images
+
     if _has_labels:
         input_dict["labels"] = token_labels if _has_token_labels else sequence_labels
 
@@ -465,10 +496,10 @@ class LayoutLMDataCollator:
     def __post_init__(self) -> None:
         assert isinstance(self.tokenizer, PreTrainedTokenizerFast), "Tokenizer must be a fast tokenizer"
         if self.return_tensors:
-            assert self.padding not in ("do_not_pad",)
-            assert self.truncation
+            assert self.padding not in ("do_not_pad",), self.padding
+            assert self.truncation, self.truncation
         if self.return_overflowing_tokens:
-            assert self.truncation
+            assert self.truncation, self.truncation
 
     def __call__(self, raw_features: Union[RawLayoutLMFeatures, List[RawLayoutLMFeatures]]) -> LayoutLMFeatures:
         """
