@@ -18,14 +18,15 @@
 """
 Module for language detection pipeline component
 """
-from typing import List, Optional
+from copy import copy, deepcopy
+from typing import Optional, Sequence
 
 from ..datapoint.image import Image
-from ..datapoint.page import Page
+from ..datapoint.view import Page
 from ..extern.base import LanguageDetector, ObjectDetector
 from ..utils.detection_types import JsonDict
 from ..utils.logger import logger
-from ..utils.settings import LayoutType, PageType
+from ..utils.settings import LayoutType, PageType, TypeOrStr, get_type
 from .base import PipelineComponent
 from .registry import pipeline_component_registry
 
@@ -50,44 +51,44 @@ class LanguageDetectionService(PipelineComponent):
       .. code-block:: python
 
           lang_detector = FasttextLangDetector(path_weights,profile.categories)
-          component = LanguageDetectionService(lang_detector, text_container="WORD",
-                                               floating_text_block_names=["TEXT","TITLE"],
-                                               text_block_names=["TEXT","TITLE",TABLE"])
+          component = LanguageDetectionService(lang_detector, text_container="word",
+                                               text_block_names=["text","title","table"])
 
     """
 
     def __init__(
         self,
         language_detector: LanguageDetector,
-        text_container: str,
+        text_container: Optional[TypeOrStr] = None,
         text_detector: Optional[ObjectDetector] = None,
-        floating_text_block_names: Optional[List[str]] = None,
-        text_block_names: Optional[List[str]] = None,
+        text_block_names: Optional[Sequence[TypeOrStr]] = None,
     ):
         """
         :param language_detector: Detector to determine text
-        :param text_container: text container, needed for generating the reading order. Not necessary when passing a
+        :param text_container: text container, needed to generate the reading order. Not necessary when passing a
                                text detector.
         :param text_detector: Object detector to extract text. You cannot use a Pdfminer here.
 
-        :param floating_text_block_names: floating text blocks, needed for generating the reading order. Not necessary
-                                          when passing a text detector.
         :param text_block_names: text blocks, needed for generating the reading order. Not necessary
                                  when passing a text detector.
         """
 
         self.predictor = language_detector
         self.text_detector = text_detector
-        self._text_container = text_container
-        self._floating_text_block_names = floating_text_block_names
-        self._text_block_names = text_block_names
+        self.text_container = get_type(text_container) if text_container is not None else text_container
+        _text_block_names = []
+        if text_block_names:
+            _text_block_names = [get_type(text_block) for text_block in text_block_names]
+        self.text_block_names = _text_block_names
         self._init_sanity_checks()
-        super().__init__(None)  # cannot use PredictorPipelineComponent class because of return type of predict meth
+        super().__init__(
+            self._get_name(self.predictor.name)
+        )  # cannot use PredictorPipelineComponent class because of return type of predict meth
 
     def serve(self, dp: Image) -> None:
         if self.text_detector is None:
-            page = Page.from_image(dp, self._text_container, self._floating_text_block_names, self._text_block_names)
-            text = page.get_text()
+            page = Page.from_image(dp, self.text_container, self.text_block_names)  # type: ignore
+            text = page.text_no_line_break
         else:
             if dp.image is None:
                 raise ValueError("dp.image cannot be None")
@@ -101,28 +102,24 @@ class LanguageDetectionService(PipelineComponent):
 
     def _init_sanity_checks(self) -> None:
         assert (
-            self.text_detector or self._text_container
+            self.text_detector or self.text_container
         ), "if no text_detector is provided a text container must be specified"
         if not self.text_detector:
-            assert self._text_container in [LayoutType.word, LayoutType.line], (
+            assert self.text_container in [LayoutType.word, LayoutType.line], (
                 f"text_container must be either {LayoutType.word} or " f"{LayoutType.line}"
             )
-            assert set(self._floating_text_block_names) <= set(  # type: ignore
-                self._text_block_names  # type: ignore
-            ), "floating_text_block_names must be a subset of text_block_names"
-            if not self._floating_text_block_names and not self._text_block_names:
-                logger.info(
-                    "floating_text_block_names and text_block_names are set to None and. "
-                    "This setting will return no reading order!"
-                )
+            if not self.text_block_names:
+                logger.info("text_block_names are set to None. This setting will return no reading order!")
 
     def clone(self) -> PipelineComponent:
+        predictor = self.predictor.clone()
+        if not isinstance(predictor, LanguageDetector):
+            raise ValueError(f"Predictor must be of type LanguageDetector, but is of type {type(predictor)}")
         return self.__class__(
-            self.predictor,
-            self._text_container,
-            self.text_detector,
-            self._floating_text_block_names,
-            self._text_block_names,
+            predictor,
+            copy(self.text_container),
+            deepcopy(self.text_detector),
+            deepcopy(self.text_block_names),
         )
 
     def get_meta_annotation(self) -> JsonDict:
@@ -134,3 +131,7 @@ class LanguageDetectionService(PipelineComponent):
                 ("summaries", [PageType.language]),
             ]
         )
+
+    @staticmethod
+    def _get_name(predictor_name: str) -> str:
+        return f"language_detection_{predictor_name}"
