@@ -18,16 +18,17 @@
 """
 Module for text extraction pipeline component
 """
-from copy import deepcopy
+from copy import copy, deepcopy
 from itertools import chain
-from typing import Dict, List, Mapping, Optional, Sequence, Tuple, Union
+from typing import Any, Dict, List, Optional, Sequence, Tuple, Union
 
 from ..datapoint.annotation import ImageAnnotation
 from ..datapoint.image import Image
 from ..extern.base import ObjectDetector, PdfMiner, TextRecognizer
+from ..extern.tessocr import TesseractOcrDetector
 from ..utils.detection_types import ImageType, JsonDict
 from ..utils.logger import logger
-from ..utils.settings import LayoutType, Relationships, TypeOrStr, WordType, get_type
+from ..utils.settings import LayoutType, PageType, Relationships, TypeOrStr, WordType, get_type
 from .base import PipelineComponent, PredictorPipelineComponent
 from .registry import pipeline_component_registry
 
@@ -68,14 +69,11 @@ class TextExtractionService(PredictorPipelineComponent):
         self,
         text_extract_detector: Union[ObjectDetector, PdfMiner, TextRecognizer],
         extract_from_roi: Optional[Union[Sequence[TypeOrStr], TypeOrStr]] = None,
-        category_id_mapping: Optional[Mapping[int, int]] = None,
+        run_time_ocr_language_selection: bool = False,
     ):
         """
         :param text_extract_detector: ObjectDetector
         :param extract_from_roi: one or more category names for roi selection
-        :param category_id_mapping: Mapping of category IDs. The word category is set to 1 without mapping.
-
-              Example: {1: 9} sets the ID of the image annotation WORD to 9.
         """
 
         if extract_from_roi is None:
@@ -85,10 +83,16 @@ class TextExtractionService(PredictorPipelineComponent):
             if isinstance(extract_from_roi, str)
             else [get_type(roi_category) for roi_category in extract_from_roi]
         )
-        super().__init__(text_extract_detector, category_id_mapping)
+        super().__init__(self._get_name(text_extract_detector.name), text_extract_detector)
         if self.extract_from_category:
             if not isinstance(self.predictor, (ObjectDetector, TextRecognizer)):
                 raise TypeError("Predicting from a cropped image requires to pass an ObjectDetector or TextRecognizer.")
+        if run_time_ocr_language_selection:
+            assert isinstance(self.predictor, TesseractOcrDetector), (
+                "Only TesseractOcrDetector supports multiple " "languages"
+            )
+
+        self.run_time_ocr_language_selection = run_time_ocr_language_selection
 
     def serve(self, dp: Image) -> None:
         maybe_batched_text_rois = self.get_text_rois(dp)
@@ -100,6 +104,8 @@ class TextExtractionService(PredictorPipelineComponent):
             if predictor_input is None:
                 raise ValueError("predictor_input cannot be None")
             width, height = None, None
+            if self.run_time_ocr_language_selection:
+                self.predictor.set_language(dp.summary.get_sub_category(PageType.language).value)  # type: ignore
             detect_result_list = self.predictor.predict(predictor_input)  # type: ignore
             if isinstance(self.predictor, PdfMiner):
                 width, height = self.predictor.get_width_height(predictor_input)  # type: ignore
@@ -193,6 +199,16 @@ class TextExtractionService(PredictorPipelineComponent):
             ]
         )
 
+    @staticmethod
+    def _get_name(text_detector_name: str) -> str:
+        return f"text_extract_{text_detector_name}"
+
+    def clone(self) -> "PredictorPipelineComponent":
+        predictor = self.predictor.clone()
+        if not isinstance(predictor, (ObjectDetector, PdfMiner, TextRecognizer)):
+            raise ValueError(f"predictor must be of type ObjectDetector or PdfMiner, but is of type {type(predictor)}")
+        return self.__class__(predictor, deepcopy(self.extract_from_category), self.run_time_ocr_language_selection)
+
 
 def _reading_lines(image_id: str, word_anns: List[ImageAnnotation]) -> List[Tuple[int, str]]:
     reading_lines = []
@@ -207,21 +223,20 @@ def _reading_lines(image_id: str, word_anns: List[ImageAnnotation]) -> List[Tupl
             row_cy = (row["upper"] + row["lower"]) / 2
 
             if (row["upper"] < bounding_box.cy < row["lower"]) or (bounding_box.uly < row_cy < bounding_box.lry):
-                reading_lines.append((idx, word.annotation_id))
+                reading_lines.append((idx, word.annotation_id, bounding_box.cx))
                 row_found = True
                 break
 
         if not row_found:
             rows.append({"upper": bounding_box.uly, "lower": bounding_box.lry})
-            reading_lines.append((len(rows) - 1, word.annotation_id))
+            reading_lines.append((len(rows) - 1, word.annotation_id, bounding_box.cx))
 
     rows_dict = {k: rows[k] for k in range(len(rows))}
     rows_dict = {
         idx: key[0] for idx, key in enumerate(sorted(rows_dict.items(), key=lambda it: it[1]["upper"]))  # type:ignore
     }
-    reading_lines.sort(key=lambda x: rows_dict[x[0]])  # type:ignore
-    reading_lines = [(idx + 1, word[1]) for idx, word in enumerate(reading_lines)]
-    return reading_lines
+    reading_lines.sort(key=lambda x: (rows_dict[x[0]], x[2]))
+    return [(idx + 1, word[1]) for idx, word in enumerate(reading_lines)]
 
 
 def _reading_columns(
@@ -229,8 +244,6 @@ def _reading_columns(
     anns: List[ImageAnnotation],
     starting_point_tolerance: float = 0.01,
     height_tolerance: float = 3.0,
-    same_line_top_tolerance: float = 0.001,
-    same_line_spacing_tolerance: float = 5.0,
 ) -> List[Tuple[int, str]]:
     reading_blocks = []
     columns: List[Dict[str, float]] = []
@@ -248,39 +261,80 @@ def _reading_columns(
 
         column_found = False
         for idx, col in enumerate(columns):
-            # if the starting point is within starting_point_tolerance (first_condition) and
-            # the top location is within height_tolerance * bbox_height (second_condition), or
-            # the new line appeared to be broken by Textract mistake and should be of the same line
-            # by looking at the top (third_condition) and
-            # the left of the new line appears right next to the right of the last line (fourth_condition)
-            # then consider the new line as part of said column
-            first_condition = abs(rel_coords_box.ulx - col["left"]) < starting_point_tolerance
-            second_condition = abs(rel_coords_box.uly - col["top"]) < height_tolerance * bounding_box.height
-            third_condition = (
-                abs(rel_coords_box.uly - col["top"]) < same_line_top_tolerance
-            )  # appeared to be in the same line
-            fourth_condition = (
-                abs(rel_coords_box.ulx - col["right"]) < same_line_spacing_tolerance * starting_point_tolerance
+            # if the x-coordinate left and right is within starting_point_tolerance (first_condition and
+            # second_condition) or if x-coordinate left and right is within the left or right border of the column
+            # then the annotation will belong to this column and column left/right will be re-adjusted
+
+            first_condition = all(
+                (
+                    col["left"] - starting_point_tolerance < rel_coords_box.ulx,
+                    rel_coords_box.lrx < col["right"] + starting_point_tolerance,
+                )
             )
-            if (first_condition and second_condition) or (third_condition and fourth_condition):
+            second_condition = all(
+                (
+                    rel_coords_box.ulx - starting_point_tolerance < col["left"],
+                    col["right"] < rel_coords_box.lrx + starting_point_tolerance,
+                )
+            )
+
+            third_condition = abs(rel_coords_box.uly - col["bottom"]) < height_tolerance * rel_coords_box.height
+            fourth_condition = abs(rel_coords_box.lry - col["top"]) < height_tolerance * rel_coords_box.height
+
+            if (first_condition and (third_condition or fourth_condition)) or (  # pylint: disable=R0916
+                second_condition and (third_condition or fourth_condition)
+            ):
                 reading_blocks.append((idx, ann.annotation_id))
                 # update the top and right with the new line added.
-                col["top"] = rel_coords_box.uly
-                col["right"] = rel_coords_box.lry
+                col["left"] = min(rel_coords_box.ulx, col["left"])
+                col["top"] = min(rel_coords_box.uly, col["top"])
+                col["right"] = max(rel_coords_box.lrx, col["right"])
+                col["bottom"] = max(rel_coords_box.lry, col["bottom"])
                 column_found = True
                 break
 
         if not column_found:
-            columns.append({"left": rel_coords_box.ulx, "right": rel_coords_box.lrx, "top": rel_coords_box.uly})
+            columns.append(
+                {
+                    "left": rel_coords_box.ulx,
+                    "right": rel_coords_box.lrx,
+                    "top": rel_coords_box.uly,
+                    "bottom": rel_coords_box.lry,
+                }
+            )
             # update the top and right with the new reading block added.
             reading_blocks.append((len(columns) - 1, ann.annotation_id))
 
-    columns_dict = {k: columns[k] for k in range(len(columns))}
-    columns_dict = {
-        idx: key[0] for idx, key in enumerate(sorted(columns_dict.items(), key=lambda it: it[1]["left"]))  # type:ignore
-    }
+    # building connected components of columns
+    connected_components: List[Dict[str, Any]] = []
+    for idx, col in enumerate(columns):
+        col["id"] = idx
+        component_found = False
+        for comp in connected_components:
+            if comp["top"] < col["top"] < comp["bottom"] or comp["top"] < col["bottom"] < comp["bottom"]:
+                comp["top"] = min(comp["top"], col["top"])
+                comp["bottom"] = max(comp["bottom"], col["bottom"])
+                comp["left"] = col["left"]
+                comp["column"].append(col)
+                component_found = True
+                break
+        if not component_found:
+            connected_components.append(
+                {"top": col["top"], "bottom": col["bottom"], "left": col["left"], "column": [col]}
+            )
+
+    # next, sorting columns in connected components by increasing x-value
+    for comp in connected_components:
+        comp["column"].sort(key=lambda x: x["left"])
+
+    # finally, sorting connected components by increasing y-value
+    connected_components.sort(key=lambda x: x["top"])
+    columns = list(chain(*[comp["column"] for comp in connected_components]))
+
+    # old to new mapping
+    columns_dict = {k: col["id"] for k, col in enumerate(columns)}
     _blocks = [(columns_dict[x[0]], x[1]) for x in reading_blocks]
-    _blocks.sort(key=lambda x: x[0])  # type:ignore
+    _blocks.sort(key=lambda x: x[0])
     reading_blocks = [(idx + 1, block[1]) for idx, block in enumerate(_blocks)]
     return reading_blocks
 
@@ -339,7 +393,9 @@ class TextOrderService(PipelineComponent):
         :param text_containers_to_text_block: Text containers are in general no text blocks and belong to a lower
                                               hierarchy. However, if a text container is not assigned to a text block
                                               you can add it to the text block ordering to ensure that the full text is
-                                              part of the subsequent sub process.
+                                              part of the subsequent sub process. Note however, that if the text
+                                              container is on word level rather than line level, the results will not be
+                                              very convincing
         """
         if isinstance(floating_text_block_names, str):
             floating_text_block_names = [floating_text_block_names]
@@ -355,13 +411,13 @@ class TextOrderService(PipelineComponent):
         self._text_block_names = text_block_names
         self._text_containers_to_text_block = text_containers_to_text_block
         self._init_sanity_checks()
-        super().__init__(None)
+        super().__init__("text_order")
 
     def serve(self, dp: Image) -> None:
         # select all text blocks that are considered to be relevant for page text. This does not include some layout
         # items that have to be considered independently (e.g. tables). Order the blocks by column wise reading order
         text_block_anns = dp.get_annotation(category_names=self._floating_text_block_names)
-
+        number_text_block_anns_orig = len(text_block_anns)
         # maybe add all text containers that are not mapped to a text block
         if self._text_containers_to_text_block:
             text_ann_ids = list(
@@ -371,11 +427,16 @@ class TextOrderService(PipelineComponent):
             text_container_anns = [ann for ann in text_container_anns if ann.annotation_id not in text_ann_ids]
             text_block_anns.extend(text_container_anns)
 
-        raw_reading_order_list = _reading_columns(dp, text_block_anns)
-        for raw_reading_order in raw_reading_order_list:
-            self.dp_manager.set_category_annotation(
-                Relationships.reading_order, raw_reading_order[0], Relationships.reading_order, raw_reading_order[1]
-            )
+        # estimating reading columns. We will only do this if we have some text blocks that are no text_containers
+        # (number_text_block_anns_orig >0) or if the text container is not a word. Otherwise, we will have to skip that
+        # part
+        if self._text_container != LayoutType.word or number_text_block_anns_orig:
+            raw_reading_order_list = _reading_columns(dp, text_block_anns, 0.05, 2.0)
+
+            for raw_reading_order in raw_reading_order_list:
+                self.dp_manager.set_category_annotation(
+                    Relationships.reading_order, raw_reading_order[0], Relationships.reading_order, raw_reading_order[1]
+                )
 
         # next we select all blocks that might contain text. We sort all text within these blocks
         block_anns = dp.get_annotation(category_names=self._text_block_names)
@@ -394,18 +455,42 @@ class TextOrderService(PipelineComponent):
         # this is the setting where we order words without having text blocks
         if not block_anns:
             text_container_anns = dp.get_annotation(category_names=self._text_container)
-            raw_reading_order_list = _reading_lines(dp.image_id, text_container_anns)
-            for raw_reading_order in raw_reading_order_list:
-                self.dp_manager.set_category_annotation(
-                    Relationships.reading_order, raw_reading_order[0], Relationships.reading_order, raw_reading_order[1]
-                )
+            # some OCR systems return textline and blocks. If they are available we will sort first by block, then by
+            # line and finally by center x coord.
+            if text_container_anns:
+                text_container_ann = text_container_anns[0]
+                if WordType.block and WordType.text_line in text_container_ann.sub_categories:
+                    text_container_position = [
+                        (
+                            int(ann.get_sub_category(WordType.block).category_id),
+                            int(ann.get_sub_category(WordType.text_line).category_id),
+                            ann.bounding_box.cx,  # type: ignore
+                            ann.annotation_id,
+                        )
+                        for ann in text_container_anns
+                    ]
+                    text_container_position.sort(key=lambda x: (x[0], x[1], x[2]))
+                    for position, element in enumerate(text_container_position):
+                        self.dp_manager.set_category_annotation(
+                            Relationships.reading_order, position, Relationships.reading_order, element[3]
+                        )
+                else:
+                    # Last try. We only form lines without and define a reading from this
+                    raw_reading_order_list = _reading_lines(dp.image_id, text_container_anns)
+                    for raw_reading_order in raw_reading_order_list:
+                        self.dp_manager.set_category_annotation(
+                            Relationships.reading_order,
+                            raw_reading_order[0],
+                            Relationships.reading_order,
+                            raw_reading_order[1],
+                        )
 
     def clone(self) -> PipelineComponent:
         return self.__class__(
-            self._text_container,
-            self._floating_text_block_names,
-            self._text_block_names,
-            self._text_containers_to_text_block,
+            copy(self._text_container),
+            deepcopy(self._floating_text_block_names),
+            deepcopy(self._text_block_names),
+            deepcopy(self._text_containers_to_text_block),
         )
 
     def _init_sanity_checks(self) -> None:
