@@ -320,7 +320,10 @@ def train_hf_layoutlm(
                 categories=LayoutType.word, sub_categories={LayoutType.word: [WordType.token_tag]}, keys=False
             )[LayoutType.word][WordType.token_tag]
         dd_model = dd_model_cls(
-            path_config_json=path_config_json, path_weights=path_weights, categories=categories, device="cuda"
+            path_config_json=path_config_json,
+            path_weights=path_weights,
+            categories=categories,
+            device="cuda",
         )
         pipeline_component_cls = pipeline_component_registry.get(pipeline_component_name)
         if dataset_type == DatasetType.sequence_classification:
