@@ -21,7 +21,7 @@ Module for globally accessible fixtures
 
 from copy import deepcopy
 from pathlib import Path
-from typing import Dict, List, Tuple
+from typing import Dict, List, Mapping, Sequence, Tuple
 
 import numpy as np
 from pytest import fixture
@@ -37,11 +37,20 @@ from deepdoctection.datapoint import (
 from deepdoctection.datasets import DatasetCategories
 from deepdoctection.extern.base import DetectionResult, SequenceClassResult, TokenClassResult
 from deepdoctection.utils.detection_types import ImageType, JsonDict
-from deepdoctection.utils.settings import names
+from deepdoctection.utils.settings import (
+    CellType,
+    LayoutType,
+    ObjectTypes,
+    Relationships,
+    WordType,
+    object_types_registry,
+    update_all_types_dict,
+)
 from deepdoctection.utils.systools import get_package_path
 
 from .data import (
     Annotations,
+    TestType,
     get_layoutlm_features,
     get_layoutlm_input,
     get_sequence_class_result,
@@ -86,19 +95,30 @@ def fixture_categories() -> Dict[str, str]:
     """
     Categories as Dict
     """
-    return {"1": names.C.TEXT, "2": names.C.TITLE, "3": names.C.TAB, "4": names.C.FIG, "5": names.C.LIST}
+    return {
+        "1": LayoutType.text,
+        "2": LayoutType.title,
+        "3": LayoutType.table,
+        "4": LayoutType.figure,
+        "5": LayoutType.list,
+    }
 
 
 @fixture(name="dataset_categories")
-def fixture_dataset_categories_categories() -> DatasetCategories:
+def fixture_dataset_categories() -> DatasetCategories:
     """
     fixture categories
     """
-    _categories = [names.C.TAB, names.C.CELL, names.C.ROW, names.C.COL]
-    _sub_categories: JsonDict = {
-        names.C.ROW: {names.C.RN: []},
-        names.C.COL: {names.C.CN: []},
-        names.C.CELL: {names.C.RN: [], names.C.CN: [], names.C.RS: [], names.C.CS: []},
+    _categories = [LayoutType.table, LayoutType.cell, LayoutType.row, LayoutType.column]
+    _sub_categories: Mapping[ObjectTypes, Mapping[ObjectTypes, Sequence[ObjectTypes]]] = {
+        LayoutType.row: {CellType.row_number: []},
+        LayoutType.column: {CellType.column_number: []},
+        LayoutType.cell: {
+            CellType.row_number: [],
+            CellType.column_number: [],
+            CellType.row_span: [],
+            CellType.column_span: [],
+        },
     }
     return DatasetCategories(_categories, _sub_categories)
 
@@ -178,9 +198,9 @@ def fixture_dp_image_tab_cell_item(dp_image: Image) -> Image:
     anns = Annotations().get_layout_annotation(segmentation=True)
     for ann in anns:
         dp_image.dump(ann)
-    table = dp_image.get_annotation(category_names=names.C.TAB)[0]
+    table = dp_image.get_annotation(category_names=LayoutType.table)[0]
     dp_image.image_ann_to_image(table.annotation_id, True)
-    table_anns = dp_image.get_annotation_iter(category_names=[names.C.CELL, names.C.ROW, names.C.COL])
+    table_anns = dp_image.get_annotation_iter(category_names=[LayoutType.cell, LayoutType.row, LayoutType.column])
     for ann in table_anns:
         assert isinstance(table.image, Image)
         table.image.dump(ann)
@@ -191,7 +211,7 @@ def fixture_dp_image_tab_cell_item(dp_image: Image) -> Image:
         assert isinstance(ann.image, Image)
         ann.image.set_embedding(table.annotation_id, ann.bounding_box)  # type: ignore
         ann.image.set_embedding(dp_image.image_id, ann_global_box)
-        table.dump_relationship(names.C.CHILD, ann.annotation_id)
+        table.dump_relationship(Relationships.child, ann.annotation_id)
     return deepcopy(dp_image)
 
 
@@ -199,10 +219,10 @@ def fixture_dp_image_tab_cell_item(dp_image: Image) -> Image:
 def fixture_dp_image_item_stretched(dp_image_tab_cell_item: Image) -> Image:
     """fixture dp_image_tab_cell_item"""
     dp = dp_image_tab_cell_item
-    table = dp.get_annotation(category_names=names.C.TAB)[0]
+    table = dp.get_annotation(category_names=LayoutType.table)[0]
     assert isinstance(table, ImageAnnotation)
-    rows = dp.get_annotation_iter(category_names=names.C.ROW)
-    cols = dp.get_annotation_iter(category_names=names.C.COL)
+    rows = dp.get_annotation_iter(category_names=LayoutType.row)
+    cols = dp.get_annotation_iter(category_names=LayoutType.column)
     assert isinstance(table.image, Image)
     table_embedding_box = table.image.get_embedding(dp.image_id)
     for row in rows:
@@ -259,9 +279,9 @@ def fixture_words_annotations_with_sub_cats(
 ) -> List[ImageAnnotation]:
     """fixture words_annotations_with_sub_cats"""
     for ann, sub_cat_list in zip(word_layout_annotations_for_ordering, word_sub_cats_for_ordering):
-        ann.dump_sub_category(names.C.CHARS, sub_cat_list[0])
-        ann.dump_sub_category(names.C.BLOCK, sub_cat_list[1])
-        ann.dump_sub_category(names.C.LINE, sub_cat_list[2])
+        ann.dump_sub_category(WordType.characters, sub_cat_list[0])
+        ann.dump_sub_category(WordType.block, sub_cat_list[1])
+        ann.dump_sub_category(LayoutType.line, sub_cat_list[2])
     return word_layout_annotations_for_ordering
 
 
@@ -279,14 +299,14 @@ def fixture_dp_image_with_layout_and_word_annotations(
     dp_image.dump(layout_anns[0])
     dp_image.dump(layout_anns[1])
     dp_image.dump(word_anns[0])
-    layout_anns[0].dump_relationship(names.C.CHILD, word_anns[0].annotation_id)
+    layout_anns[0].dump_relationship(Relationships.child, word_anns[0].annotation_id)
     dp_image.dump(word_anns[1])
-    layout_anns[0].dump_relationship(names.C.CHILD, word_anns[1].annotation_id)
+    layout_anns[0].dump_relationship(Relationships.child, word_anns[1].annotation_id)
 
     dp_image.dump(word_anns[2])
-    layout_anns[1].dump_relationship(names.C.CHILD, word_anns[2].annotation_id)
+    layout_anns[1].dump_relationship(Relationships.child, word_anns[2].annotation_id)
     dp_image.dump(word_anns[3])
-    layout_anns[1].dump_relationship(names.C.CHILD, word_anns[3].annotation_id)
+    layout_anns[1].dump_relationship(Relationships.child, word_anns[3].annotation_id)
     return dp_image
 
 
@@ -300,19 +320,19 @@ def fixture_dp_image_fully_segmented(
     """fixture dp_image_fully_segmented"""
 
     dp = dp_image_item_stretched
-    rows = dp.get_annotation_iter(category_names=names.C.ROW)
-    cols = dp.get_annotation_iter(category_names=names.C.COL)
+    rows = dp.get_annotation_iter(category_names=LayoutType.row)
+    cols = dp.get_annotation_iter(category_names=LayoutType.column)
     for row, col, row_sub_cat, col_sub_cat in zip(rows, cols, row_sub_cats, col_sub_cats):
-        row.dump_sub_category(names.C.RN, row_sub_cat)
-        col.dump_sub_category(names.C.CN, col_sub_cat)
+        row.dump_sub_category(CellType.row_number, row_sub_cat)
+        col.dump_sub_category(CellType.column_number, col_sub_cat)
 
-    cells = dp.get_annotation_iter(category_names=[names.C.CELL, names.C.HEAD, names.C.BODY])
+    cells = dp.get_annotation_iter(category_names=[LayoutType.cell, CellType.header, CellType.body])
 
     for cell, sub_cats in zip(cells, cell_sub_cats):
-        cell.dump_sub_category(names.C.RN, sub_cats[0])
-        cell.dump_sub_category(names.C.CN, sub_cats[1])
-        cell.dump_sub_category(names.C.RS, sub_cats[2])
-        cell.dump_sub_category(names.C.CS, sub_cats[3])
+        cell.dump_sub_category(CellType.row_number, sub_cats[0])
+        cell.dump_sub_category(CellType.column_number, sub_cats[1])
+        cell.dump_sub_category(CellType.row_span, sub_cats[2])
+        cell.dump_sub_category(CellType.column_span, sub_cats[3])
 
     return deepcopy(dp)
 
@@ -353,20 +373,20 @@ def fixture_dp_image_fully_segmented_fully_tiled(
     """
 
     dp = dp_image_item_stretched
-    rows = dp.get_annotation_iter(category_names=names.C.ROW)
-    cols = dp.get_annotation_iter(category_names=names.C.COL)
+    rows = dp.get_annotation_iter(category_names=LayoutType.row)
+    cols = dp.get_annotation_iter(category_names=LayoutType.column)
     for row, col, row_sub_cat, col_sub_cat in zip(rows, cols, row_sub_cats, col_sub_cats):
-        row.dump_sub_category(names.C.RN, row_sub_cat)
-        col.dump_sub_category(names.C.CN, col_sub_cat)
+        row.dump_sub_category(CellType.row_number, row_sub_cat)
+        col.dump_sub_category(CellType.column_number, col_sub_cat)
 
     cell_sub_cats = cell_sub_cats_when_table_fully_tiled
-    cells = dp.get_annotation_iter(category_names=[names.C.CELL, names.C.HEAD, names.C.BODY])
+    cells = dp.get_annotation_iter(category_names=[LayoutType.cell, CellType.header, CellType.body])
 
     for cell, sub_cats in zip(cells, cell_sub_cats):
-        cell.dump_sub_category(names.C.RN, sub_cats[0])
-        cell.dump_sub_category(names.C.CN, sub_cats[1])
-        cell.dump_sub_category(names.C.RS, sub_cats[2])
-        cell.dump_sub_category(names.C.CS, sub_cats[3])
+        cell.dump_sub_category(CellType.row_number, sub_cats[0])
+        cell.dump_sub_category(CellType.column_number, sub_cats[1])
+        cell.dump_sub_category(CellType.row_span, sub_cats[2])
+        cell.dump_sub_category(CellType.column_span, sub_cats[3])
 
     return deepcopy(dp)
 
@@ -466,3 +486,9 @@ def fixture_text_lines() -> List[Tuple[str, ImageType]]:
 def fixture_language_detect_result() -> DetectionResult:
     """fixture language_detect_result"""
     return DetectionResult(text="eng", score=0.9876)
+
+
+def pytest_sessionstart() -> None:
+    """Pre configuration before testing starts"""
+    object_types_registry.register("TestType", func=TestType)
+    update_all_types_dict()
